==> randomwaifupics-0.1.tar.gz: randomwaifupics-0.1/setup.py <==
from distutils.core import setup
setup(
  name = 'randomwaifupics',         
  packages = ['/dynastybot'],   # Chose the same as "name"
  version = '0.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'waifu pics api wrapper',   # Give a short description about your library
  author = 'Nksama',                   # Type in your name
  author_email = 'Nksama@protonmail.com',      # Type in your E-Mail
  url = 'https://github.com/Nksama',   # Provide either the link to your github or to your website
#  download_url = 'https://github.com/user/reponame/archive/v_01.tar.gz',    # I explain this later on
  keywords = ["waifu" ,"pics"],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'validators',
          "requests"
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)

==> randomwaifupics-1.0.tar.gz: randomwaifupics-1.0/setup.py <==
from distutils.core import setup
setup(
  name = 'randomwaifupics',         
  packages = ['/dynastybot'],   # Chose the same as "name"
  version = '1.0',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'waifu pics api wrapper',   # Give a short description about your library
  author = 'Nksama',                   # Type in your name
  author_email = 'Nksama@protonmail.com',      # Type in your E-Mail
  url = 'https://github.com/Nksama',   # Provide either the link to your github or to your website
  download_url = 'https://download1499.mediafire.com/ns5up58wck6g/gp7pua5cq9wcgqf/randomwaifupics-1.0.tar.gz',    # I explain this later on
  keywords = ["waifu" ,"pics"],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'validators',
          "requests"
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
